% (C) 2002 Dominique Unruh, LPPL
% The macros in the Thai part are oriented on TIS620, i.e. each
% letter in TIS620 is represented by exactly one macro. 
% No reordering whatsoever is required.
%
\NeedsTeXFormat{LaTeX2e}[1998/12/01]
\ProvidesFile{c90enc.def}[2002/06/06 Encoding C90 for Thai]
\DeclareFontEncoding{C90}{}{}
\DeclareFontSubstitution{C90}{nrsr}{m}{n}
%
\DeclareTextSymbol{\textemdash}{C90}{"0C}
\DeclareTextSymbol{\textendash}{C90}{"0B}
\DeclareTextSymbol{\textquotedbl}{C90}{"11}
\DeclareTextSymbol{\textquotedblleft}{C90}{"0DD}
\DeclareTextSymbol{\textquotedblright}{C90}{"22}
\DeclareTextSymbol{\textquoteleft}{C90}{`\`}
\DeclareTextSymbol{\textquoteright}{C90}{`\'}
\DeclareTextSymbol{\textbraceleft}{C90}{`\{}
\DeclareTextSymbol{\textbraceright}{C90}{`\}}
\DeclareTextSymbol{\textbar}{C90}{`\|}
%
\DeclareTextSymbol{\thaiKoKai}{C90}{161}
\DeclareTextSymbol{\thaiKhoKhai}{C90}{162}
\DeclareTextSymbol{\thaiKhoKhuat}{C90}{163}
\DeclareTextSymbol{\thaiKhoKhwai}{C90}{164}
\DeclareTextSymbol{\thaiKhoKhon}{C90}{165}
\DeclareTextSymbol{\thaiKhoRakhang}{C90}{166}
\DeclareTextSymbol{\thaiNgoNgu}{C90}{167}
\DeclareTextSymbol{\thaiChoChan}{C90}{168}
\DeclareTextSymbol{\thaiChoChing}{C90}{169}
\DeclareTextSymbol{\thaiChoChang}{C90}{170}
\DeclareTextSymbol{\thaiSoSo}{C90}{171}
\DeclareTextSymbol{\thaiChoChoe}{C90}{172}
\DeclareTextSymbol{\thaiYoYing}{C90}{173}
\DeclareTextSymbol{\thaiDoChada}{C90}{174}
\DeclareTextSymbol{\thaiToPatak}{C90}{175}
\DeclareTextSymbol{\thaiThoThan}{C90}{176}
\DeclareTextSymbol{\thaiThoNangmontho}{C90}{177}
\DeclareTextSymbol{\thaiThoPhuthao}{C90}{178}
\DeclareTextSymbol{\thaiNoNen}{C90}{179}
\DeclareTextSymbol{\thaiDoDek}{C90}{180}
\DeclareTextSymbol{\thaiToTao}{C90}{181}
\DeclareTextSymbol{\thaiThoThung}{C90}{182}
\DeclareTextSymbol{\thaiThoThahan}{C90}{183}
\DeclareTextSymbol{\thaiThoThong}{C90}{184}
\DeclareTextSymbol{\thaiNoNu}{C90}{185}
\DeclareTextSymbol{\thaiBoBaimai}{C90}{186}
\DeclareTextSymbol{\thaiPoPla}{C90}{187}
\DeclareTextSymbol{\thaiPhoPhung}{C90}{188}
\DeclareTextSymbol{\thaiFoFa}{C90}{189}
\DeclareTextSymbol{\thaiPhoPhan}{C90}{190}
\DeclareTextSymbol{\thaiFoFan}{C90}{191}
\DeclareTextSymbol{\thaiPhoSamphao}{C90}{192}
\DeclareTextSymbol{\thaiMoMa}{C90}{193}
\DeclareTextSymbol{\thaiYoYak}{C90}{194}
\DeclareTextSymbol{\thaiRoRua}{C90}{195}
\DeclareTextSymbol{\thaiRu}{C90}{196}
\DeclareTextSymbol{\thaiLoLing}{C90}{197}
\DeclareTextSymbol{\thaiLu}{C90}{198}
\DeclareTextSymbol{\thaiWoWaen}{C90}{199}
\DeclareTextSymbol{\thaiSoSala}{C90}{200}
\DeclareTextSymbol{\thaiSoRusi}{C90}{201}
\DeclareTextSymbol{\thaiSoSua}{C90}{202}
\DeclareTextSymbol{\thaiHoHip}{C90}{203}
\DeclareTextSymbol{\thaiLoChula}{C90}{204}
\DeclareTextSymbol{\thaiOAng}{C90}{205}
\DeclareTextSymbol{\thaiHoNokhuk}{C90}{206}
\DeclareTextSymbol{\thaiPaiyannoi}{C90}{207}
\DeclareTextSymbol{\thaiSaraA}{C90}{208}
\DeclareTextSymbol{\thaiMaiHanakat}{C90}{209}
\DeclareTextSymbol{\thaiSaraAa}{C90}{210}
\DeclareTextSymbol{\thaiSaraAm}{C90}{211}
\DeclareTextSymbol{\thaiSaraI}{C90}{212}
\DeclareTextSymbol{\thaiSaraIi}{C90}{213}
\DeclareTextSymbol{\thaiSaraUe}{C90}{214}
\DeclareTextSymbol{\thaiSaraUee}{C90}{215}
\DeclareTextSymbol{\thaiSaraU}{C90}{216}
\DeclareTextSymbol{\thaiSaraUu}{C90}{217}
\DeclareTextSymbol{\thaiPhinthu}{C90}{218}
\DeclareTextSymbol{\textbaht}{C90}{223}
\DeclareTextSymbol{\thaiSaraE}{C90}{224}
\DeclareTextSymbol{\thaiSaraAe}{C90}{225}
\DeclareTextSymbol{\thaiSaraO}{C90}{226}
\DeclareTextSymbol{\thaiSaraAiMaimuan}{C90}{227}
\DeclareTextSymbol{\thaiSaraAiMaimalai}{C90}{228}
\DeclareTextSymbol{\thaiLakkhangyao}{C90}{229}
\DeclareTextSymbol{\thaiMaiyamok}{C90}{230}
\DeclareTextSymbol{\thaiMaitaikhu}{C90}{231}
\DeclareTextSymbol{\thaiMaiEk}{C90}{232}
\DeclareTextSymbol{\thaiMaiTho}{C90}{233}
\DeclareTextSymbol{\thaiMaiTri}{C90}{234}
\DeclareTextSymbol{\thaiMaiChattawa}{C90}{235}
\DeclareTextSymbol{\thaiThanthakhat}{C90}{236}
\DeclareTextSymbol{\thaiNikhahit}{C90}{237}
\DeclareTextSymbol{\thaiYamakkan}{C90}{238}
\DeclareTextSymbol{\thaiFongman}{C90}{239}
\DeclareTextSymbol{\thaizero}{C90}{240}
\DeclareTextSymbol{\thaione}{C90}{241}
\DeclareTextSymbol{\thaitwo}{C90}{242}
\DeclareTextSymbol{\thaithree}{C90}{243}
\DeclareTextSymbol{\thaifour}{C90}{244}
\DeclareTextSymbol{\thaifive}{C90}{245}
\DeclareTextSymbol{\thaisix}{C90}{246}
\DeclareTextSymbol{\thaiseven}{C90}{247}
\DeclareTextSymbol{\thaieight}{C90}{248}
\DeclareTextSymbol{\thainine}{C90}{249}
\DeclareTextSymbol{\thaiAngkhankhu}{C90}{250}
\DeclareTextSymbol{\thaiKhomut}{C90}{251}
%
\endinput
